Improve this Doc

# `ngParseExt`

## Installation

First, get the file:

- Google CDN e.g.

      "//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-parse-ext.js"

- NPM e.g.

      npm install --save angular-parse-ext@X.Y.Z

  or

      yarn add angular-parse-ext@X.Y.Z

- Bower e.g.

      bower install angular-parse-ext#X.Y.Z

- code.angularjs.org (discouraged for production use) e.g.

      "//code.angularjs.org/X.Y.Z/angular-parse-ext.js"

where X.Y.Z is the AngularJS version you are running.

Then, include `angular-parse-ext.js` in your HTML:

    <script src="path/to/angular.js"></script>
    <script src="path/to/angular-parse-ext.js"></script>

Finally, load the module in your application by adding it as a dependent module:

    angular.module('app', ['ngParseExt']);

With that you're ready to get started!

# ngParseExt

The `ngParseExt` module provides functionality to allow Unicode characters in identifiers inside Angular expressions.

This module allows the usage of any identifier that follows ES6 identifier naming convention to be used as an identifier in an Angular expression. ES6 delegates some of the identifier rules definition to Unicode, this module uses ES6 and Unicode 8.0 identifiers convention.